==> blesta-5.10.2.zip: blesta/language/da_dk/admin_billing.php <==
<?php
/**
 * Admin Billing
 *
 * @package blesta
 * @subpackage blesta.language.da_dk
 * @copyright Copyright (c) 2024, Phillips Data, Inc.
 * @license http://www.blesta.com/license/ The Blesta License Agreement
 * @link http://www.blesta.com/ Blesta
 */

$lang['AdminBilling.!success.invoices_marked_printed'] = 'De valgte fakturaer er blevet markeret som udskrevet.';
$lang['AdminBilling.!success.services_scheduled_cancel'] = 'De valgte tjenester var planlagt til at blive annulleret.';
$lang['AdminBilling.!success.services_scheduled_uncancel'] = 'De valgte tjenester er ikke længere planlagt til at blive aflyst.';
$lang['AdminBilling.!success.services_pushed'] = 'De valgte tjenester blev med succes skubbet til den nye klient.';
$lang['AdminBilling.!error.no_invoices_selected'] = 'Der er ikke valgt nogen fakturaer.';
$lang['AdminBilling.!error.invalid_passphrase'] = 'Den indtastede passphrase er ugyldig.';
$lang['AdminBilling.!error.future_cancel_date'] = 'Den planlagte afbestillingsdato må ikke ligge i fortiden.';
$lang['AdminBilling.index.open_parethesis'] = '(';
$lang['AdminBilling.index.closed_parethesis'] = ')';
$lang['AdminBilling.index.page_title'] = 'Oversigt over fakturering';
$lang['AdminBilling.index.manage_widgets'] = 'Administrer widgets';
$lang['AdminBilling.index.customize_dashboard'] = 'Tilpas oversigt';
$lang['AdminBilling.index.heading_actions'] = 'Handlingspunkter';
$lang['AdminBilling.index.no_actions'] = 'Ingen udestående punkter.';
$lang['AdminBilling.index.action_printqueue'] = 'Varer, der afventer udskrivning';
$lang['AdminBilling.index.action_batch'] = 'Varer, der afventer batch';
$lang['AdminBilling.updatedashboard.text_layout'] = 'Vælg et layout nedenfor for at tilpasse din faktureringsoversigt.';
$lang['AdminBilling.managewidgets.text_widgets'] = 'Træk widgets fra højre til venstre for at tilføje dem til din faktureringsoversigt, eller fra venstre til højre for at fjerne dem.';
$lang['AdminBilling.managewidgets.text_version'] = 'ver %1$s';
$lang['AdminBilling.managewidgets.text_author'] = 'Forfatter:';
$lang['AdminBilling.invoices.page_title'] = 'Fakturering af fakturaer';
$lang['AdminBilling.invoices.boxtitle_invoices'] = 'Fakturaer';
$lang['AdminBilling.invoices.heading_invoice'] = 'Faktura #';
$lang['AdminBilling.invoices.heading_recurinvoice'] = 'Tilbagevendende #';
$lang['AdminBilling.invoices.heading_client'] = 'Kunde #';
$lang['AdminBilling.invoices.heading_amount'] = 'Beløb';
$lang['AdminBilling.invoices.heading_paid'] = 'Betalt';
$lang['AdminBilling.invoices.heading_due'] = 'På grund af';
$lang['AdminBilling.invoices.heading_dateclosed'] = 'Dato Lukket';
$lang['AdminBilling.invoices.heading_datebilled'] = 'Dato for fakturering';
$lang['AdminBilling.invoices.heading_datedue'] = 'Dato forfalden';
$lang['AdminBilling.invoices.heading_options'] = 'Valgmuligheder';
$lang['AdminBilling.invoices.heading_term'] = 'Betegnelse';
$lang['AdminBilling.invoices.heading_duration'] = 'Varighed';
$lang['AdminBilling.invoices.heading_count'] = 'Tæl';
$lang['AdminBilling.invoices.category_open'] = 'Åben';
$lang['AdminBilling.invoices.category_drafts'] = 'Kladder';
$lang['AdminBilling.invoices.category_closed'] = 'Lukket';
$lang['AdminBilling.invoices.category_voided'] = 'Annulleret';
$lang['AdminBilling.invoices.category_pastdue'] = 'Forfaldne';
$lang['AdminBilling.invoices.category_pending'] = 'Afventer';
$lang['AdminBilling.invoices.category_recurring'] = 'Tilbagevendende';
$lang['AdminBilling.invoices.option_edit'] = 'Rediger';
$lang['AdminBilling.invoices.option_view'] = 'Se';
$lang['AdminBilling.invoices.option_pay'] = 'Løn';
$lang['AdminBilling.invoices.subtotal_w_tax'] = '%1$s +skat';
$lang['AdminBilling.invoices.term_day'] = '%1$s dag';
$lang['AdminBilling.invoices.term_week'] = '%1$s uge';
$lang['AdminBilling.invoices.term_month'] = '%1$s måned';
$lang['AdminBilling.invoices.term_year'] = '%1$s år';
$lang['AdminBilling.invoices.term_day_plural'] = '%1$s dage';
$lang['AdminBilling.invoices.term_week_plural'] = '%1$s uger';
$lang['AdminBilling.invoices.term_month_plural'] = '%1$s måneder';
$lang['AdminBilling.invoices.term_year_plural'] = '%1$s år';
$lang['AdminBilling.invoices.duration_finite'] = '%1$s gange';
$lang['AdminBilling.invoices.duration_infinite'] = '∞';
$lang['AdminBilling.invoices.no_results'] = 'Der er ingen fakturaer med denne status.';
$lang['AdminBilling.quotations.page_title'] = 'Faktureringscitater';
$lang['AdminBilling.quotations.boxtitle_quotations'] = 'Citater';
$lang['AdminBilling.quotations.heading_quotation'] = 'Citat #';
$lang['AdminBilling.quotations.heading_client'] = 'Kunde #';
$lang['AdminBilling.quotations.heading_title'] = 'Titel';
$lang['AdminBilling.quotations.heading_staff'] = 'Citeret af';
$lang['AdminBilling.quotations.heading_subtotal'] = 'Subtotal';
$lang['AdminBilling.quotations.heading_total'] = 'Beløb';
$lang['AdminBilling.quotations.heading_date_created'] = 'Dato for oprettelse';
$lang['AdminBilling.quotations.heading_date_expires'] = 'Udløbsdato';
$lang['AdminBilling.quotations.heading_options'] = 'Valgmuligheder';
$lang['AdminBilling.quotations.option_edit'] = 'Rediger';
$lang['AdminBilling.quotations.option_view'] = 'Se';
$lang['AdminBilling.quotations.option_invoice'] = 'Opret faktura';
$lang['AdminBilling.quotations.option_approve'] = 'Godkend';
$lang['AdminBilling.quotations.confirm_approve'] = 'Er du sikker på, at du vil godkende dette citat?';
$lang['AdminBilling.quotations.no_results'] = 'Der er ingen tilbud med denne status.';
$lang['AdminBilling.quotationinvoices.headingexpand_invoice'] = 'Faktura #';
$lang['AdminBilling.quotationinvoices.headingexpand_amount'] = 'Beløb';
$lang['AdminBilling.quotationinvoices.headingexpand_paid'] = 'Betalt';
$lang['AdminBilling.quotationinvoices.headingexpand_date_billed'] = 'Dato for fakturering';
$lang['AdminBilling.quotationinvoices.headingexpand_options'] = 'Valgmuligheder';
$lang['AdminBilling.quotationinvoices.option_view'] = 'Se';
$lang['AdminBilling.quotationinvoices.invoices_no_results'] = 'Der er ingen fakturaer knyttet til dette tilbud.';
$lang['AdminBilling.services.page_title'] = 'Faktureringstjenester';
$lang['AdminBilling.services.boxtitle_services'] = 'Tjenester';
$lang['AdminBilling.services.heading_client'] = 'Kunde #';
$lang['AdminBilling.services.heading_package'] = 'Pakke';
$lang['AdminBilling.services.heading_label'] = 'Etiket';
$lang['AdminBilling.services.heading_term'] = 'Betegnelse';
$lang['AdminBilling.services.heading_dateadded'] = 'Dato tilføjet';
$lang['AdminBilling.services.heading_daterenews'] = 'Dato Fornyer';
$lang['AdminBilling.services.heading_datesuspended'] = 'Dato Suspenderet';
$lang['AdminBilling.services.heading_datecanceled'] = 'Dato Annulleret';
$lang['AdminBilling.services.heading_options'] = 'Valgmuligheder';
$lang['AdminBilling.services.option_manage'] = 'Administrer';
$lang['AdminBilling.services.option_delete'] = 'Slet';
$lang['AdminBilling.services.confirm_delete'] = 'Er du sikker på, at du vil slette denne tjeneste?';
$lang['AdminBilling.services.category_active'] = 'Aktiv';
$lang['AdminBilling.services.category_canceled'] = 'Aflyst';
$lang['AdminBilling.services.category_suspended'] = 'Suspenderet';
$lang['AdminBilling.services.category_pending'] = 'Afventer';
$lang['AdminBilling.services.category_in_review'] = 'En gennemgang';
$lang['AdminBilling.services.category_scheduled_cancellation'] = 'Planlagt';
$lang['AdminBilling.services.text_never'] = 'Aldrig';
$lang['AdminBilling.services.no_results'] = 'Der er ingen tjenester med denne status.';
$lang['AdminBilling.services.recurring_term'] = '%1$s %2$s @ %3$s';
$lang['AdminBilling.services.action.schedule_cancellation'] = 'Aflysning af tidsplan';
$lang['AdminBilling.services.action.field_action_type_term'] = 'Slutningen af perioden';
$lang['AdminBilling.services.action.field_action_type_date'] = 'Specifik dato';
$lang['AdminBilling.services.action.field_action_type_none'] = 'Aflys ikke';
$lang['AdminBilling.services.action.push_to_client'] = 'Push til klient';
$lang['AdminBilling.services.action.field_client'] = 'Kunde:';
$lang['AdminBilling.services.field_actionsubmit'] = 'Indsend';
$lang['AdminBilling.serviceinfo.no_results'] = 'Denne tjeneste har ingen detaljer.';
$lang['AdminBilling.serviceinfo.cancellation_reason'] = 'Årsag til aflysning: %1$s';
$lang['AdminBilling.transactions.page_title'] = 'Faktureringstransaktioner';
$lang['AdminBilling.transactions.boxtitle_transactions'] = 'Transaktioner';
$lang['AdminBilling.transactions.heading_client'] = 'Kunde #';
$lang['AdminBilling.transactions.heading_type'] = 'Type';
$lang['AdminBilling.transactions.heading_amount'] = 'Beløb';
$lang['AdminBilling.transactions.heading_credit'] = 'Krediteret';
$lang['AdminBilling.transactions.heading_applied'] = 'Anvendt';
$lang['AdminBilling.transactions.heading_number'] = 'Antal';
$lang['AdminBilling.transactions.heading_reference_id'] = 'Reference #';
$lang['AdminBilling.transactions.heading_date'] = 'Dato';
$lang['AdminBilling.transactions.heading_options'] = 'Valgmuligheder';
$lang['AdminBilling.transactions.category_approved'] = 'Godkendt';
$lang['AdminBilling.transactions.category_declined'] = 'Afvist';
$lang['AdminBilling.transactions.category_voided'] = 'Annulleret';
$lang['AdminBilling.transactions.category_error'] = 'Fejl';
$lang['AdminBilling.transactions.category_pending'] = 'Afventer';
$lang['AdminBilling.transactions.category_refunded'] = 'Refunderet';
$lang['AdminBilling.transactions.category_returned'] = 'Returneret';
$lang['AdminBilling.transactions.option_edit'] = 'Rediger';
$lang['AdminBilling.transactions.no_results'] = 'Der er ingen transaktioner med denne status.';
$lang['AdminBilling.transactions.headingexpand_invoice'] = 'Faktura';
$lang['AdminBilling.transactions.headingexpand_amount'] = 'Beløb';
$lang['AdminBilling.transactions.headingexpand_appliedon'] = 'Anvendt på';
$lang['AdminBilling.transactions.applied_no_results'] = 'Denne transaktion er ikke blevet anvendt på nogen fakturaer.';
$lang['AdminBilling.invoices.headingexpand_paymenttype'] = 'Betalingstype';
$lang['AdminBilling.invoices.headingexpand_amount'] = 'Beløb';
$lang['AdminBilling.invoices.headingexpand_applied'] = 'Anvendt';
$lang['AdminBilling.invoices.headingexpand_appliedon'] = 'Anvendt på';
$lang['AdminBilling.invoices.headingexpand_options'] = 'Valgmuligheder';
$lang['AdminBilling.invoices.applied_no_results'] = 'Denne faktura har ingen transaktioner.';
$lang['AdminBilling.invoices.text_edit'] = 'Rediger';
$lang['AdminBilling.printqueue.page_title'] = 'Kø til fakturaudskrivning';
$lang['AdminBilling.printqueue.category_to_print'] = 'Udskriv';
$lang['AdminBilling.printqueue.category_printed'] = 'Tidligere trykt';
$lang['AdminBilling.printqueue.boxtitle_printqueue'] = 'Udskriftskø';
$lang['AdminBilling.printqueue.no_results_printed'] = 'Der er ingen tidligere udskrevne fakturaer.';
$lang['AdminBilling.printqueue.no_results_to_print'] = 'Der er ingen fakturaer i kø til at blive udskrevet.';
$lang['AdminBilling.printqueue.heading_invoice'] = 'Faktura #';
$lang['AdminBilling.printqueue.heading_client'] = 'Kunde #';
$lang['AdminBilling.printqueue.heading_amount'] = 'Beløb';
$lang['AdminBilling.printqueue.heading_paid'] = 'Betalt';
$lang['AdminBilling.printqueue.heading_due'] = 'På grund af';
$lang['AdminBilling.printqueue.heading_datebilled'] = 'Dato for fakturering';
$lang['AdminBilling.printqueue.heading_datedue'] = 'Dato forfalden';
$lang['AdminBilling.printqueue.heading_deliverydatesent'] = 'Dato sendt';
$lang['AdminBilling.printqueue.text_printsubmit'] = 'Udskriv';
$lang['AdminBilling.printqueue.text_marksubmit'] = 'Mærke Trykt';
$lang['AdminBilling.batch.page_title'] = 'Fakturering Batch';
$lang['AdminBilling.batch.boxtitle_batch'] = 'Batch';
$lang['AdminBilling.batch.no_passphrase'] = 'Manuel batchbehandling er ikke aktiveret.';
$lang['AdminBilling.batch.text_description'] = 'Indtast din adgangskode for manuelt at batchbehandle alle fakturaer, der er planlagt til automatisk debitering med en lokalt gemt betalingskonto.';
$lang['AdminBilling.batch.field_passphrase'] = 'Adgangssætning';
$lang['AdminBilling.batch.text_batchsubmit'] = 'Batch-proces';

==> blesta-5.11.4.zip: blesta/language/da_dk/admin_billing.php <==
<?php
/**
 * Admin Billing
 *
 * @package blesta
 * @subpackage blesta.language.da_dk
 * @copyright Copyright (c) 2025, Phillips Data, Inc.
 * @license http://www.blesta.com/license/ The Blesta License Agreement
 * @link http://www.blesta.com/ Blesta
 */

$lang['AdminBilling.!success.invoices_marked_printed'] = 'De valgte fakturaer er blevet markeret som udskrevet.';
$lang['AdminBilling.!success.services_scheduled_cancel'] = 'De valgte tjenester var planlagt til at blive annulleret.';
$lang['AdminBilling.!success.services_scheduled_uncancel'] = 'De valgte tjenester er ikke længere planlagt til at blive aflyst.';
$lang['AdminBilling.!success.services_pushed'] = 'De valgte tjenester blev med succes skubbet til den nye klient.';
$lang['AdminBilling.!error.no_invoices_selected'] = 'Der er ikke valgt nogen fakturaer.';
$lang['AdminBilling.!error.invalid_passphrase'] = 'Den indtastede passphrase er ugyldig.';
$lang['AdminBilling.!error.future_cancel_date'] = 'Den planlagte afbestillingsdato må ikke ligge i fortiden.';
$lang['AdminBilling.index.open_parethesis'] = '(';
$lang['AdminBilling.index.closed_parethesis'] = ')';
$lang['AdminBilling.index.page_title'] = 'Oversigt over fakturering';
$lang['AdminBilling.index.manage_widgets'] = 'Administrer widgets';
$lang['AdminBilling.index.customize_dashboard'] = 'Tilpas oversigt';
$lang['AdminBilling.index.heading_actions'] = 'Handlingspunkter';
$lang['AdminBilling.index.no_actions'] = 'Ingen udestående punkter.';
$lang['AdminBilling.index.action_printqueue'] = 'Varer, der afventer udskrivning';
$lang['AdminBilling.index.action_batch'] = 'Varer, der afventer batch';
$lang['AdminBilling.updatedashboard.text_layout'] = 'Vælg et layout nedenfor for at tilpasse din faktureringsoversigt.';
$lang['AdminBilling.managewidgets.text_widgets'] = 'Træk widgets fra højre til venstre for at tilføje dem til din faktureringsoversigt, eller fra venstre til højre for at fjerne dem.';
$lang['AdminBilling.managewidgets.text_version'] = 'ver %1$s';
$lang['AdminBilling.managewidgets.text_author'] = 'Forfatter:';
$lang['AdminBilling.invoices.page_title'] = 'Fakturering af fakturaer';
$lang['AdminBilling.invoices.boxtitle_invoices'] = 'Fakturaer';
$lang['AdminBilling.invoices.heading_invoice'] = 'Faktura #';
$lang['AdminBilling.invoices.heading_recurinvoice'] = 'Tilbagevendende #';
$lang['AdminBilling.invoices.heading_client'] = 'Kunde #';
$lang['AdminBilling.invoices.heading_amount'] = 'Beløb';
$lang['AdminBilling.invoices.heading_paid'] = 'Betalt';
$lang['AdminBilling.invoices.heading_due'] = 'På grund af';
$lang['AdminBilling.invoices.heading_dateclosed'] = 'Dato Lukket';
$lang['AdminBilling.invoices.heading_datebilled'] = 'Dato for fakturering';
$lang['AdminBilling.invoices.heading_datedue'] = 'Dato forfalden';
$lang['AdminBilling.invoices.heading_options'] = 'Valgmuligheder';
$lang['AdminBilling.invoices.heading_term'] = 'Betegnelse';
$lang['AdminBilling.invoices.heading_duration'] = 'Varighed';
$lang['AdminBilling.invoices.heading_count'] = 'Tæl';
$lang['AdminBilling.invoices.category_open'] = 'Åben';
$lang['AdminBilling.invoices.category_drafts'] = 'Kladder';
$lang['AdminBilling.invoices.category_closed'] = 'Lukket';
$lang['AdminBilling.invoices.category_voided'] = 'Annulleret';
$lang['AdminBilling.invoices.category_pastdue'] = 'Forfaldne';
$lang['AdminBilling.invoices.category_pending'] = 'Afventer';
$lang['AdminBilling.invoices.category_recurring'] = 'Tilbagevendende';
$lang['AdminBilling.invoices.option_edit'] = 'Rediger';
$lang['AdminBilling.invoices.option_view'] = 'Se';
$lang['AdminBilling.invoices.option_pay'] = 'Løn';
$lang['AdminBilling.invoices.subtotal_w_tax'] = '%1$s +skat';
$lang['AdminBilling.invoices.term_day'] = '%1$s dag';
$lang['AdminBilling.invoices.term_week'] = '%1$s uge';
$lang['AdminBilling.invoices.term_month'] = '%1$s måned';
$lang['AdminBilling.invoices.term_year'] = '%1$s år';
$lang['AdminBilling.invoices.term_day_plural'] = '%1$s dage';
$lang['AdminBilling.invoices.term_week_plural'] = '%1$s uger';
$lang['AdminBilling.invoices.term_month_plural'] = '%1$s måneder';
$lang['AdminBilling.invoices.term_year_plural'] = '%1$s år';
$lang['AdminBilling.invoices.duration_finite'] = '%1$s gange';
$lang['AdminBilling.invoices.duration_infinite'] = '∞';
$lang['AdminBilling.invoices.no_results'] = 'Der er ingen fakturaer med denne status.';
$lang['AdminBilling.quotations.page_title'] = 'Faktureringscitater';
$lang['AdminBilling.quotations.boxtitle_quotations'] = 'Citater';
$lang['AdminBilling.quotations.heading_quotation'] = 'Citat #';
$lang['AdminBilling.quotations.heading_client'] = 'Kunde #';
$lang['AdminBilling.quotations.heading_title'] = 'Titel';
$lang['AdminBilling.quotations.heading_staff'] = 'Citeret af';
$lang['AdminBilling.quotations.heading_subtotal'] = 'Subtotal';
$lang['AdminBilling.quotations.heading_total'] = 'Beløb';
$lang['AdminBilling.quotations.heading_date_created'] = 'Dato for oprettelse';
$lang['AdminBilling.quotations.heading_date_expires'] = 'Udløbsdato';
$lang['AdminBilling.quotations.heading_options'] = 'Valgmuligheder';
$lang['AdminBilling.quotations.option_edit'] = 'Rediger';
$lang['AdminBilling.quotations.option_view'] = 'Se';
$lang['AdminBilling.quotations.option_invoice'] = 'Opret faktura';
$lang['AdminBilling.quotations.option_approve'] = 'Godkend';
$lang['AdminBilling.quotations.confirm_approve'] = 'Er du sikker på, at du vil godkende dette citat?';
$lang['AdminBilling.quotations.no_results'] = 'Der er ingen tilbud med denne status.';
$lang['AdminBilling.quotationinvoices.headingexpand_invoice'] = 'Faktura #';
$lang['AdminBilling.quotationinvoices.headingexpand_amount'] = 'Beløb';
$lang['AdminBilling.quotationinvoices.headingexpand_paid'] = 'Betalt';
$lang['AdminBilling.quotationinvoices.headingexpand_date_billed'] = 'Dato for fakturering';
$lang['AdminBilling.quotationinvoices.headingexpand_options'] = 'Valgmuligheder';
$lang['AdminBilling.quotationinvoices.option_view'] = 'Se';
$lang['AdminBilling.quotationinvoices.invoices_no_results'] = 'Der er ingen fakturaer knyttet til dette tilbud.';
$lang['AdminBilling.services.page_title'] = 'Faktureringstjenester';
$lang['AdminBilling.services.boxtitle_services'] = 'Tjenester';
$lang['AdminBilling.services.heading_client'] = 'Kunde #';
$lang['AdminBilling.services.heading_package'] = 'Pakke';
$lang['AdminBilling.services.heading_label'] = 'Etiket';
$lang['AdminBilling.services.heading_term'] = 'Betegnelse';
$lang['AdminBilling.services.heading_dateadded'] = 'Dato tilføjet';
$lang['AdminBilling.services.heading_daterenews'] = 'Dato Fornyer';
$lang['AdminBilling.services.heading_datesuspended'] = 'Dato Suspenderet';
$lang['AdminBilling.services.heading_datecanceled'] = 'Dato Annulleret';
$lang['AdminBilling.services.heading_options'] = 'Valgmuligheder';
$lang['AdminBilling.services.option_manage'] = 'Administrer';
$lang['AdminBilling.services.option_delete'] = 'Slet';
$lang['AdminBilling.services.confirm_delete'] = 'Er du sikker på, at du vil slette denne tjeneste?';
$lang['AdminBilling.services.category_active'] = 'Aktiv';
$lang['AdminBilling.services.category_canceled'] = 'Aflyst';
$lang['AdminBilling.services.category_suspended'] = 'Suspenderet';
$lang['AdminBilling.services.category_pending'] = 'Afventer';
$lang['AdminBilling.services.category_in_review'] = 'En gennemgang';
$lang['AdminBilling.services.category_scheduled_cancellation'] = 'Planlagt';
$lang['AdminBilling.services.text_never'] = 'Aldrig';
$lang['AdminBilling.services.no_results'] = 'Der er ingen tjenester med denne status.';
$lang['AdminBilling.services.recurring_term'] = '%1$s %2$s @ %3$s';
$lang['AdminBilling.services.action.schedule_cancellation'] = 'Aflysning af tidsplan';
$lang['AdminBilling.services.action.field_action_type_term'] = 'Slutningen af perioden';
$lang['AdminBilling.services.action.field_action_type_date'] = 'Specifik dato';
$lang['AdminBilling.services.action.field_action_type_none'] = 'Aflys ikke';
$lang['AdminBilling.services.action.push_to_client'] = 'Push til klient';
$lang['AdminBilling.services.action.field_client'] = 'Kunde:';
$lang['AdminBilling.services.field_actionsubmit'] = 'Indsend';
$lang['AdminBilling.serviceinfo.no_results'] = 'Denne tjeneste har ingen detaljer.';
$lang['AdminBilling.serviceinfo.cancellation_reason'] = 'Årsag til aflysning: %1$s';
$lang['AdminBilling.transactions.page_title'] = 'Faktureringstransaktioner';
$lang['AdminBilling.transactions.boxtitle_transactions'] = 'Transaktioner';
$lang['AdminBilling.transactions.heading_client'] = 'Kunde #';
$lang['AdminBilling.transactions.heading_type'] = 'Type';
$lang['AdminBilling.transactions.heading_amount'] = 'Beløb';
$lang['AdminBilling.transactions.heading_credit'] = 'Krediteret';
$lang['AdminBilling.transactions.heading_applied'] = 'Anvendt';
$lang['AdminBilling.transactions.heading_number'] = 'Antal';
$lang['AdminBilling.transactions.heading_reference_id'] = 'Reference #';
$lang['AdminBilling.transactions.heading_date'] = 'Dato';
$lang['AdminBilling.transactions.heading_options'] = 'Valgmuligheder';
$lang['AdminBilling.transactions.category_approved'] = 'Godkendt';
$lang['AdminBilling.transactions.category_declined'] = 'Afvist';
$lang['AdminBilling.transactions.category_voided'] = 'Annulleret';
$lang['AdminBilling.transactions.category_error'] = 'Fejl';
$lang['AdminBilling.transactions.category_pending'] = 'Afventer';
$lang['AdminBilling.transactions.category_refunded'] = 'Refunderet';
$lang['AdminBilling.transactions.category_returned'] = 'Returneret';
$lang['AdminBilling.transactions.option_edit'] = 'Rediger';
$lang['AdminBilling.transactions.no_results'] = 'Der er ingen transaktioner med denne status.';
$lang['AdminBilling.transactions.headingexpand_invoice'] = 'Faktura';
$lang['AdminBilling.transactions.headingexpand_amount'] = 'Beløb';
$lang['AdminBilling.transactions.headingexpand_appliedon'] = 'Anvendt på';
$lang['AdminBilling.transactions.applied_no_results'] = 'Denne transaktion er ikke blevet anvendt på nogen fakturaer.';
$lang['AdminBilling.invoices.headingexpand_paymenttype'] = 'Betalingstype';
$lang['AdminBilling.invoices.headingexpand_amount'] = 'Beløb';
$lang['AdminBilling.invoices.headingexpand_applied'] = 'Anvendt';
$lang['AdminBilling.invoices.headingexpand_appliedon'] = 'Anvendt på';
$lang['AdminBilling.invoices.headingexpand_options'] = 'Valgmuligheder';
$lang['AdminBilling.invoices.applied_no_results'] = 'Denne faktura har ingen transaktioner.';
$lang['AdminBilling.invoices.text_edit'] = 'Rediger';
$lang['AdminBilling.printqueue.page_title'] = 'Kø til fakturaudskrivning';
$lang['AdminBilling.printqueue.category_to_print'] = 'Udskriv';
$lang['AdminBilling.printqueue.category_printed'] = 'Tidligere trykt';
$lang['AdminBilling.printqueue.boxtitle_printqueue'] = 'Udskriftskø';
$lang['AdminBilling.printqueue.no_results_printed'] = 'Der er ingen tidligere udskrevne fakturaer.';
$lang['AdminBilling.printqueue.no_results_to_print'] = 'Der er ingen fakturaer i kø til at blive udskrevet.';
$lang['AdminBilling.printqueue.heading_invoice'] = 'Faktura #';
$lang['AdminBilling.printqueue.heading_client'] = 'Kunde #';
$lang['AdminBilling.printqueue.heading_amount'] = 'Beløb';
$lang['AdminBilling.printqueue.heading_paid'] = 'Betalt';
$lang['AdminBilling.printqueue.heading_due'] = 'På grund af';
$lang['AdminBilling.printqueue.heading_datebilled'] = 'Dato for fakturering';
$lang['AdminBilling.printqueue.heading_datedue'] = 'Dato forfalden';
$lang['AdminBilling.printqueue.heading_deliverydatesent'] = 'Dato sendt';
$lang['AdminBilling.printqueue.text_printsubmit'] = 'Udskriv';
$lang['AdminBilling.printqueue.text_marksubmit'] = 'Mærke Trykt';
$lang['AdminBilling.batch.page_title'] = 'Fakturering Batch';
$lang['AdminBilling.batch.boxtitle_batch'] = 'Batch';
$lang['AdminBilling.batch.no_passphrase'] = 'Manuel batchbehandling er ikke aktiveret.';
$lang['AdminBilling.batch.text_description'] = 'Indtast din adgangskode for manuelt at batchbehandle alle fakturaer, der er planlagt til automatisk debitering med en lokalt gemt betalingskonto.';
$lang['AdminBilling.batch.field_passphrase'] = 'Adgangssætning';
$lang['AdminBilling.batch.text_batchsubmit'] = 'Batch-proces';
$lang['AdminBilling.services.action.field_suspension_reason'] = 'Årsag til suspension:';
$lang['AdminBilling.services.action.unsuspend'] = 'Ophængning';
$lang['AdminBilling.services.action.suspend'] = 'Suspendere';
$lang['AdminBilling.!success.services_unsuspended'] = 'De valgte tjenester blev afbrudt med succes.';
$lang['AdminBilling.!success.services_suspended'] = 'De valgte tjenester blev suspenderet med succes.';
